@@ -26,7 +26,7 @@ from shlex import quote
 import json
 
 from inspect import getcoroutinelocals, iscoroutine
-from clu import AMQPClient, AMQPReply, BaseClient
+from clu import AMQPClient, AMQPReply, BaseClient, CommandStatus
 
 from .exceptions import ProxyPartialInvokeException, ProxyActorIsNotReachableException
 
@@ -140,10 +140,27 @@ class Proxy():
         return not self.amqpc.connection.connection.is_closed
 
 
+
+    async def _handle_command_reply(self, fu):
+
+        ret = await fu
+
+        if hasattr(ret, "status") and ret.status.did_fail:
+            raise self._errorMapToException(ret.replies[-1].message['error'])
+
+        return ProxyDict(ret.replies[-1].message)
+
+
+    def _handle_callback(self, callback: Optional[Callable[[AMQPReply], None]], reply: AMQPReply):
+        msg = ProxyDict(json.loads(reply.message.body))
+        msg.command_status = CommandStatus.code_to_status(reply.message_code)
+        msg.sender = reply.sender
+        callback(msg)
+
     async def call_command(self,
                            command: str,
                            *args,
-                           callback: Optional[Callable[[AMQPReply], None]] = None,
+                           callback: Optional[Callable[[dict], None]] = None,
                            time_limit: Optional[float] = 42.0,
                            nowait:Bool = False,
                            object_hook: Optional[Callable[[AMQPReply], None]] = None,
@@ -161,17 +178,15 @@ class Proxy():
         fu = await self.amqpc.send_command(self.actor,
                                                 command,
                                                 *args,
-                                                callback=callback,
+                                                callback=partial(self._handle_callback, callback) if callback else None,
                                                 time_limit=time_limit)
         
-        if nowait: return fu
 
-        ret = await fu
 
-        if hasattr(ret, "status") and ret.status.did_fail:
-            raise self._errorMapToException(ret.replies[-1].message['error'])
+        if nowait: return self._handle_command_reply(fu)
+
+        return await self._handle_command_reply(fu)
 
-        return ProxyDict(ret.replies[-1].message)
 
     @staticmethod
     def _errorMapToException(em):
